@@ -4,7 +4,7 @@ require DynaLoader;
 
 use strict;
 use vars qw($VERSION @ISA);
-$VERSION = "0.1.9";
+$VERSION = "0.2.0";
 @ISA = qw/DynaLoader/;
 
 bootstrap Net::RabbitMQ $VERSION ;
@@ -57,6 +57,7 @@ C<$options> is an optional hash respecting the following keys:
        channel_max => $cmax,    #default 0
        frame_max => $fmax,      #default 131072
        heartbeat => $hearbeat,  #default 0
+       timeout => $seconds      #default undef (no timeout)
      }
 
 =item disconnect()
@@ -120,8 +121,13 @@ C<$options> is an optional hash respecting the following keys:
        auto_delete => $boolean, #default 1
      }
 
-This method returns the queuename delcared (important for retrieving
-the autogenerated queuename in the event that one was requested).
+In scalar context, this method returns the queuename delcared
+(important for retrieving the autogenerated queuename in the
+event that one was requested).
+
+In array context, this method returns three items: queuename,
+the number of message waiting on the queue, and the number
+of consumers bound to the queue.
 
 =item queue_bind($channel, $queuename, $exchange, $routing_key)
 
@@ -290,6 +296,12 @@ C<$options> is an optional hash respecting the following keys:
 
 Set quality of service flags on the current $channel.
 
+=item hearbeat()
+
+Send a hearbeat frame.  If you've connected with a heartbeat parameter,
+you must send a heartbeat periodically matching connection parameter or
+the server may snip the connection.
+
 =item basic_return($channel, $subroutine)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
